==> members-feign-airport4-20241028.083116-36-sources.jar: com/bizvane/members/feign/service/MbrMemberFeign.java <==
package com.bizvane.members.feign.service;

import com.bizvane.members.feign.model.bo.*;
import com.bizvane.members.feign.model.vo.MbrMembersDetailVO;
import com.bizvane.members.feign.model.vo.MbrMembersVO;
import com.bizvane.utils.responseinfo.PageInfo;
import com.bizvane.utils.responseinfo.ResponseData;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.data.repository.query.Param;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;

@FeignClient(value="${feign.client.members.name}",path="${feign.client.members.path}/member")
@Api("会员管理")
public interface MbrMemberFeign {

    @ApiOperation(value = "查询会员列表")
    @RequestMapping(value="/list", method = RequestMethod.POST)
    PageInfo<MbrMembersVO> list(@RequestBody MbrMemberListRequestParam param);

    @ApiOperation(value = "通过手机号查询会员")
    @RequestMapping(value="/getMemberByPhone", method = RequestMethod.POST)
    MbrMembersVO getMemberByPhone(@RequestParam("phone") String phone);

    @ApiOperation(value = "查询会员详情")
    @RequestMapping(value="/detail", method = RequestMethod.POST)
    MbrMembersDetailVO detail(@RequestParam("mbrMembersCode") String mbrMembersCode);

    @ApiOperation(value = "通过手机号或者unioinId查询会员")
    @RequestMapping(value="/getMemberByPhoneOrUnionId", method = RequestMethod.POST)
    MbrMembersVO getMemberByPhoneOrUnionId(@RequestBody MbrMemberQueryRequestParam param);

    @ApiOperation(value = "开卡")
    @RequestMapping(value="/openCard", method = RequestMethod.POST)
    ResponseData<Boolean>  openCard(@RequestBody MbrOpenCardRequestParam param);

    @ApiOperation(value = "更新会员资料")
    @RequestMapping(value="/update", method = RequestMethod.POST)
    ResponseData<Boolean> update(@RequestBody MbrMemberUpdateRequestParam updateRequestParam);

    @ApiOperation(value = "会员冻结/解冻接口")
    @RequestMapping(value="/frozenOrUnFrozen", method = RequestMethod.POST)
    ResponseData<Boolean> frozenOrUnFrozen(@RequestBody MbrMemberFrozenRequestParam param);

}

==> members-feign-airport4-20241029.104546-37-sources.jar: com/bizvane/members/feign/service/MbrMemberFeign.java <==
package com.bizvane.members.feign.service;

import com.bizvane.members.feign.model.bo.*;
import com.bizvane.members.feign.model.vo.MbrMembersDetailVO;
import com.bizvane.members.feign.model.vo.MbrMembersVO;
import com.bizvane.members.feign.model.vo.MbrOrderConsumeVO;
import com.bizvane.utils.responseinfo.PageInfo;
import com.bizvane.utils.responseinfo.ResponseData;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.data.repository.query.Param;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;

@FeignClient(value="${feign.client.members.name}",path="${feign.client.members.path}/member")
@Api("会员管理")
public interface MbrMemberFeign {

    @ApiOperation(value = "查询会员列表")
    @RequestMapping(value="/list", method = RequestMethod.POST)
    PageInfo<MbrMembersVO> list(@RequestBody MbrMemberListRequestParam param);

    @ApiOperation(value = "通过手机号查询会员")
    @RequestMapping(value="/getMemberByPhone", method = RequestMethod.POST)
    MbrMembersVO getMemberByPhone(@RequestParam("phone") String phone);

    @ApiOperation(value = "查询会员详情")
    @RequestMapping(value="/detail", method = RequestMethod.POST)
    MbrMembersDetailVO detail(@RequestParam("mbrMembersCode") String mbrMembersCode);

    @ApiOperation(value = "通过手机号或者unioinId查询会员")
    @RequestMapping(value="/getMemberByPhoneOrUnionId", method = RequestMethod.POST)
    MbrMembersVO getMemberByPhoneOrUnionId(@RequestBody MbrMemberQueryRequestParam param);

    @ApiOperation(value = "开卡")
    @RequestMapping(value="/openCard", method = RequestMethod.POST)
    ResponseData<Boolean>  openCard(@RequestBody MbrOpenCardRequestParam param);

    @ApiOperation(value = "更新会员资料")
    @RequestMapping(value="/update", method = RequestMethod.POST)
    ResponseData<Boolean> update(@RequestBody MbrMemberUpdateRequestParam updateRequestParam);

    @ApiOperation(value = "会员冻结/解冻接口")
    @RequestMapping(value="/frozenOrUnFrozen", method = RequestMethod.POST)
    ResponseData<Boolean> frozenOrUnFrozen(@RequestBody MbrMemberFrozenRequestParam param);

    @ApiOperation(value = "查询会员消费信息")
    @RequestMapping(value="/getMbrConsume", method = RequestMethod.POST)
    ResponseData<MbrOrderConsumeVO> getMbrConsume(@RequestParam("mbrMembersCode") String mbrMembersCode);
}
